lilypondparsertools.SchemeParser
================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser

.. autoclass:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.debug
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.lexer
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.lexer_rules_object
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.logger
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.logger_path
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.output_path
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_boolean__BOOLEAN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_constant__boolean
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_constant__number
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_constant__string
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_data__EMPTY
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_data__data__datum
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__constant
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__list
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__symbol
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__vector
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_error
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_expression__QUOTE__datum
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_expression__constant
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_expression__variable
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_form__expression
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_forms__EMPTY
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_forms__forms__form
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_list__L_PAREN__data__R_PAREN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_list__L_PAREN__data__datum__PERIOD__datum__R_PAREN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_number__DECIMAL
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_number__HEXADECIMAL
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_number__INTEGER
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_program__forms
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_string__STRING
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_symbol__IDENTIFIER
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_variable__IDENTIFIER
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_vector__HASH__L_PAREN__data__R_PAREN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.parser
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.parser_rules_object
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.pickle_path
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_BOOLEAN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_DECIMAL
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_HASH
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_HEXADECIMAL
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_IDENTIFIER
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_INTEGER
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_L_PAREN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_R_PAREN
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_anything
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_error
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_newline
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_440
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_443
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_446
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_456
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_error
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_whitespace
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.tokenize
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__call__
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__eq__
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__format__
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__ne__
      ~abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__repr__

Bases
-----

- :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.debug
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.lexer
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.lexer_rules_object
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.logger
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.logger_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.output_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.parser
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.parser_rules_object
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.pickle_path
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_boolean__BOOLEAN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_constant__boolean
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_constant__number
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_constant__string
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_data__EMPTY
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_data__data__datum
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__constant
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__list
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__symbol
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_datum__vector
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_expression__QUOTE__datum
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_expression__constant
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_expression__variable
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_form__expression
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_forms__EMPTY
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_forms__forms__form
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_list__L_PAREN__data__R_PAREN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_list__L_PAREN__data__datum__PERIOD__datum__R_PAREN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_number__DECIMAL
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_number__HEXADECIMAL
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_number__INTEGER
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_program__forms
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_string__STRING
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_symbol__IDENTIFIER
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_variable__IDENTIFIER
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.p_vector__HASH__L_PAREN__data__R_PAREN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_BOOLEAN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_DECIMAL
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_HASH
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_HEXADECIMAL
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_IDENTIFIER
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_INTEGER
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_L_PAREN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_R_PAREN
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_anything
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_newline
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_440
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_443
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_446
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_456
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_quote_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.t_whitespace
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.tokenize
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__call__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SchemeParser.SchemeParser.__repr__
   :noindex:
